RemoteTask class
A native VTODO task as returned by a task-capable backend.
Constructors
- RemoteTask({required String ref, required UnicalTask task, String? etag})
-
Creates a remote task.
const
Properties
- etag → String?
-
Opaque change tag for conflict detection.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- ref → String
-
Backend-assigned identity.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- task → UnicalTask
-
The domain task.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited